Index: lemon/bits/graph_extender.h
===================================================================
--- lemon/bits/graph_extender.h	(revision 77)
+++ lemon/bits/graph_extender.h	(revision 78)
@@ -65,9 +65,9 @@
     }
 
-    Node oppositeNode(const Node &n, const Arc &e) const {
-      if (n == Parent::source(e))
-	return Parent::target(e);
-      else if(n==Parent::target(e))
-	return Parent::source(e);
+    Node oppositeNode(const Node &node, const Arc &arc) const {
+      if (node == Parent::source(arc))
+	return Parent::target(arc);
+      else if(node == Parent::target(arc))
+	return Parent::source(arc);
       else
 	return INVALID;
@@ -96,5 +96,5 @@
 
     class NodeIt : public Node { 
-      const Digraph* digraph;
+      const Digraph* _digraph;
     public:
 
@@ -103,13 +103,13 @@
       NodeIt(Invalid i) : Node(i) { }
 
-      explicit NodeIt(const Digraph& _digraph) : digraph(&_digraph) {
-	_digraph.first(static_cast<Node&>(*this));
-      }
-
-      NodeIt(const Digraph& _digraph, const Node& node) 
-	: Node(node), digraph(&_digraph) {}
+      explicit NodeIt(const Digraph& digraph) : _digraph(&digraph) {
+	_digraph->first(static_cast<Node&>(*this));
+      }
+
+      NodeIt(const Digraph& digraph, const Node& node) 
+	: Node(node), _digraph(&digraph) {}
 
       NodeIt& operator++() { 
-	digraph->next(*this);
+	_digraph->next(*this);
 	return *this; 
       }
@@ -119,5 +119,5 @@
 
     class ArcIt : public Arc { 
-      const Digraph* digraph;
+      const Digraph* _digraph;
     public:
 
@@ -126,13 +126,13 @@
       ArcIt(Invalid i) : Arc(i) { }
 
-      explicit ArcIt(const Digraph& _digraph) : digraph(&_digraph) {
-	_digraph.first(static_cast<Arc&>(*this));
-      }
-
-      ArcIt(const Digraph& _digraph, const Arc& e) : 
-	Arc(e), digraph(&_digraph) { }
+      explicit ArcIt(const Digraph& digraph) : _digraph(&digraph) {
+	_digraph->first(static_cast<Arc&>(*this));
+      }
+
+      ArcIt(const Digraph& digraph, const Arc& arc) : 
+	Arc(arc), _digraph(&digraph) { }
 
       ArcIt& operator++() { 
-	digraph->next(*this);
+	_digraph->next(*this);
 	return *this; 
       }
@@ -142,5 +142,5 @@
 
     class OutArcIt : public Arc { 
-      const Digraph* digraph;
+      const Digraph* _digraph;
     public:
 
@@ -149,14 +149,14 @@
       OutArcIt(Invalid i) : Arc(i) { }
 
-      OutArcIt(const Digraph& _digraph, const Node& node) 
-	: digraph(&_digraph) {
-	_digraph.firstOut(*this, node);
-      }
-
-      OutArcIt(const Digraph& _digraph, const Arc& arc) 
-	: Arc(arc), digraph(&_digraph) {}
+      OutArcIt(const Digraph& digraph, const Node& node) 
+	: _digraph(&digraph) {
+	_digraph->firstOut(*this, node);
+      }
+
+      OutArcIt(const Digraph& digraph, const Arc& arc) 
+	: Arc(arc), _digraph(&digraph) {}
 
       OutArcIt& operator++() { 
-	digraph->nextOut(*this);
+	_digraph->nextOut(*this);
 	return *this; 
       }
@@ -166,5 +166,5 @@
 
     class InArcIt : public Arc { 
-      const Digraph* digraph;
+      const Digraph* _digraph;
     public:
 
@@ -173,14 +173,14 @@
       InArcIt(Invalid i) : Arc(i) { }
 
-      InArcIt(const Digraph& _digraph, const Node& node) 
-	: digraph(&_digraph) {
-	_digraph.firstIn(*this, node);
-      }
-
-      InArcIt(const Digraph& _digraph, const Arc& arc) : 
-	Arc(arc), digraph(&_digraph) {}
+      InArcIt(const Digraph& digraph, const Node& node) 
+	: _digraph(&digraph) {
+	_digraph->firstIn(*this, node);
+      }
+
+      InArcIt(const Digraph& digraph, const Arc& arc) : 
+	Arc(arc), _digraph(&digraph) {}
 
       InArcIt& operator++() { 
-	digraph->nextIn(*this);
+	_digraph->nextIn(*this);
 	return *this; 
       }
@@ -191,6 +191,6 @@
     ///
     /// Returns the base node (i.e. the source in this case) of the iterator
-    Node baseNode(const OutArcIt &e) const {
-      return Parent::source(e);
+    Node baseNode(const OutArcIt &arc) const {
+      return Parent::source(arc);
     }
     /// \brief Running node of the iterator
@@ -198,6 +198,6 @@
     /// Returns the running node (i.e. the target in this case) of the
     /// iterator
-    Node runningNode(const OutArcIt &e) const {
-      return Parent::target(e);
+    Node runningNode(const OutArcIt &arc) const {
+      return Parent::target(arc);
     }
 
@@ -205,6 +205,6 @@
     ///
     /// Returns the base node (i.e. the target in this case) of the iterator
-    Node baseNode(const InArcIt &e) const {
-      return Parent::target(e);
+    Node baseNode(const InArcIt &arc) const {
+      return Parent::target(arc);
     }
     /// \brief Running node of the iterator
@@ -212,6 +212,6 @@
     /// Returns the running node (i.e. the source in this case) of the
     /// iterator
-    Node runningNode(const InArcIt &e) const {
-      return Parent::source(e);
+    Node runningNode(const InArcIt &arc) const {
+      return Parent::source(arc);
     }
 
@@ -325,5 +325,5 @@
   };
 
-  /// \ingroup graphbits
+  /// \ingroup _graphbits
   ///
   /// \brief Extender for the Graphs
@@ -333,5 +333,5 @@
     
     typedef Base Parent;
-    typedef GraphExtender Digraph;
+    typedef GraphExtender Graph;
 
     typedef True UndirectedTag;
@@ -376,11 +376,11 @@
     }
 
-    Arc oppositeArc(const Arc &e) const {
-      return Parent::direct(e, !Parent::direction(e));
+    Arc oppositeArc(const Arc &arc) const {
+      return Parent::direct(arc, !Parent::direction(arc));
     }
 
     using Parent::direct;
-    Arc direct(const Edge &ue, const Node &s) const {
-      return Parent::direct(ue, Parent::source(ue) == s);
+    Arc direct(const Edge &edge, const Node &node) const {
+      return Parent::direct(edge, Parent::source(edge) == node);
     }
 
@@ -415,5 +415,5 @@
 
     class NodeIt : public Node { 
-      const Digraph* digraph;
+      const Graph* _graph;
     public:
 
@@ -422,13 +422,13 @@
       NodeIt(Invalid i) : Node(i) { }
 
-      explicit NodeIt(const Digraph& _digraph) : digraph(&_digraph) {
-	_digraph.first(static_cast<Node&>(*this));
-      }
-
-      NodeIt(const Digraph& _digraph, const Node& node) 
-	: Node(node), digraph(&_digraph) {}
+      explicit NodeIt(const Graph& graph) : _graph(&graph) {
+	_graph->first(static_cast<Node&>(*this));
+      }
+
+      NodeIt(const Graph& graph, const Node& node) 
+	: Node(node), _graph(&graph) {}
 
       NodeIt& operator++() { 
-	digraph->next(*this);
+	_graph->next(*this);
 	return *this; 
       }
@@ -438,5 +438,5 @@
 
     class ArcIt : public Arc { 
-      const Digraph* digraph;
+      const Graph* _graph;
     public:
 
@@ -445,13 +445,13 @@
       ArcIt(Invalid i) : Arc(i) { }
 
-      explicit ArcIt(const Digraph& _digraph) : digraph(&_digraph) {
-	_digraph.first(static_cast<Arc&>(*this));
-      }
-
-      ArcIt(const Digraph& _digraph, const Arc& e) : 
-	Arc(e), digraph(&_digraph) { }
+      explicit ArcIt(const Graph& graph) : _graph(&graph) {
+	_graph->first(static_cast<Arc&>(*this));
+      }
+
+      ArcIt(const Graph& graph, const Arc& arc) : 
+	Arc(arc), _graph(&graph) { }
 
       ArcIt& operator++() { 
-	digraph->next(*this);
+	_graph->next(*this);
 	return *this; 
       }
@@ -461,5 +461,5 @@
 
     class OutArcIt : public Arc { 
-      const Digraph* digraph;
+      const Graph* _graph;
     public:
 
@@ -468,14 +468,14 @@
       OutArcIt(Invalid i) : Arc(i) { }
 
-      OutArcIt(const Digraph& _digraph, const Node& node) 
-	: digraph(&_digraph) {
-	_digraph.firstOut(*this, node);
-      }
-
-      OutArcIt(const Digraph& _digraph, const Arc& arc) 
-	: Arc(arc), digraph(&_digraph) {}
+      OutArcIt(const Graph& graph, const Node& node) 
+	: _graph(&graph) {
+	_graph->firstOut(*this, node);
+      }
+
+      OutArcIt(const Graph& graph, const Arc& arc) 
+	: Arc(arc), _graph(&graph) {}
 
       OutArcIt& operator++() { 
-	digraph->nextOut(*this);
+	_graph->nextOut(*this);
 	return *this; 
       }
@@ -485,5 +485,5 @@
 
     class InArcIt : public Arc { 
-      const Digraph* digraph;
+      const Graph* _graph;
     public:
 
@@ -492,14 +492,14 @@
       InArcIt(Invalid i) : Arc(i) { }
 
-      InArcIt(const Digraph& _digraph, const Node& node) 
-	: digraph(&_digraph) {
-	_digraph.firstIn(*this, node);
-      }
-
-      InArcIt(const Digraph& _digraph, const Arc& arc) : 
-	Arc(arc), digraph(&_digraph) {}
+      InArcIt(const Graph& graph, const Node& node) 
+	: _graph(&graph) {
+	_graph->firstIn(*this, node);
+      }
+
+      InArcIt(const Graph& graph, const Arc& arc) : 
+	Arc(arc), _graph(&graph) {}
 
       InArcIt& operator++() { 
-	digraph->nextIn(*this);
+	_graph->nextIn(*this);
 	return *this; 
       }
@@ -509,5 +509,5 @@
 
     class EdgeIt : public Parent::Edge { 
-      const Digraph* digraph;
+      const Graph* _graph;
     public:
 
@@ -516,39 +516,39 @@
       EdgeIt(Invalid i) : Edge(i) { }
 
-      explicit EdgeIt(const Digraph& _digraph) : digraph(&_digraph) {
-	_digraph.first(static_cast<Edge&>(*this));
-      }
-
-      EdgeIt(const Digraph& _digraph, const Edge& e) : 
-	Edge(e), digraph(&_digraph) { }
+      explicit EdgeIt(const Graph& graph) : _graph(&graph) {
+	_graph->first(static_cast<Edge&>(*this));
+      }
+
+      EdgeIt(const Graph& graph, const Edge& edge) : 
+	Edge(edge), _graph(&graph) { }
 
       EdgeIt& operator++() { 
-	digraph->next(*this);
-	return *this; 
-      }
-
-    };
-
-    class IncArcIt : public Parent::Edge {
+	_graph->next(*this);
+	return *this; 
+      }
+
+    };
+
+    class IncEdgeIt : public Parent::Edge {
       friend class GraphExtender;
-      const Digraph* digraph;
-      bool direction;
-    public:
-
-      IncArcIt() { }
-
-      IncArcIt(Invalid i) : Edge(i), direction(false) { }
-
-      IncArcIt(const Digraph& _digraph, const Node &n) : digraph(&_digraph) {
-	_digraph.firstInc(*this, direction, n);
-      }
-
-      IncArcIt(const Digraph& _digraph, const Edge &ue, const Node &n)
-	: digraph(&_digraph), Edge(ue) {
-	direction = (_digraph.source(ue) == n);
-      }
-
-      IncArcIt& operator++() {
-	digraph->nextInc(*this, direction);
+      const Graph* _graph;
+      bool _direction;
+    public:
+
+      IncEdgeIt() { }
+
+      IncEdgeIt(Invalid i) : Edge(i), _direction(false) { }
+
+      IncEdgeIt(const Graph& graph, const Node &node) : _graph(&graph) {
+	_graph->firstInc(*this, _direction, node);
+      }
+
+      IncEdgeIt(const Graph& graph, const Edge &edge, const Node &node)
+	: _graph(&graph), Edge(edge) {
+	_direction = (_graph->source(edge) == node);
+      }
+
+      IncEdgeIt& operator++() {
+	_graph->nextInc(*this, _direction);
 	return *this; 
       }
@@ -558,6 +558,6 @@
     ///
     /// Returns the base node (ie. the source in this case) of the iterator
-    Node baseNode(const OutArcIt &e) const {
-      return Parent::source(static_cast<const Arc&>(e));
+    Node baseNode(const OutArcIt &arc) const {
+      return Parent::source(static_cast<const Arc&>(arc));
     }
     /// \brief Running node of the iterator
@@ -565,6 +565,6 @@
     /// Returns the running node (ie. the target in this case) of the
     /// iterator
-    Node runningNode(const OutArcIt &e) const {
-      return Parent::target(static_cast<const Arc&>(e));
+    Node runningNode(const OutArcIt &arc) const {
+      return Parent::target(static_cast<const Arc&>(arc));
     }
 
@@ -572,6 +572,6 @@
     ///
     /// Returns the base node (ie. the target in this case) of the iterator
-    Node baseNode(const InArcIt &e) const {
-      return Parent::target(static_cast<const Arc&>(e));
+    Node baseNode(const InArcIt &arc) const {
+      return Parent::target(static_cast<const Arc&>(arc));
     }
     /// \brief Running node of the iterator
@@ -579,6 +579,6 @@
     /// Returns the running node (ie. the source in this case) of the
     /// iterator
-    Node runningNode(const InArcIt &e) const {
-      return Parent::source(static_cast<const Arc&>(e));
+    Node runningNode(const InArcIt &arc) const {
+      return Parent::source(static_cast<const Arc&>(arc));
     }
 
@@ -586,12 +586,12 @@
     ///
     /// Returns the base node of the iterator
-    Node baseNode(const IncArcIt &e) const {
-      return e.direction ? source(e) : target(e);
+    Node baseNode(const IncEdgeIt &edge) const {
+      return edge._direction ? source(edge) : target(edge);
     }
     /// Running node of the iterator
     ///
     /// Returns the running node of the iterator
-    Node runningNode(const IncArcIt &e) const {
-      return e.direction ? target(e) : source(e);
+    Node runningNode(const IncEdgeIt &edge) const {
+      return edge._direction ? target(edge) : source(edge);
     }
 
@@ -600,13 +600,13 @@
     template <typename _Value>
     class NodeMap 
-      : public MapExtender<DefaultMap<Digraph, Node, _Value> > {
-    public:
-      typedef GraphExtender Digraph;
-      typedef MapExtender<DefaultMap<Digraph, Node, _Value> > Parent;
-
-      NodeMap(const Digraph& digraph) 
-	: Parent(digraph) {}
-      NodeMap(const Digraph& digraph, const _Value& value) 
-	: Parent(digraph, value) {}
+      : public MapExtender<DefaultMap<Graph, Node, _Value> > {
+    public:
+      typedef GraphExtender Graph;
+      typedef MapExtender<DefaultMap<Graph, Node, _Value> > Parent;
+
+      NodeMap(const Graph& graph) 
+	: Parent(graph) {}
+      NodeMap(const Graph& graph, const _Value& value) 
+	: Parent(graph, value) {}
 
       NodeMap& operator=(const NodeMap& cmap) {
@@ -624,13 +624,13 @@
     template <typename _Value>
     class ArcMap 
-      : public MapExtender<DefaultMap<Digraph, Arc, _Value> > {
-    public:
-      typedef GraphExtender Digraph;
-      typedef MapExtender<DefaultMap<Digraph, Arc, _Value> > Parent;
-
-      ArcMap(const Digraph& digraph) 
-	: Parent(digraph) {}
-      ArcMap(const Digraph& digraph, const _Value& value) 
-	: Parent(digraph, value) {}
+      : public MapExtender<DefaultMap<Graph, Arc, _Value> > {
+    public:
+      typedef GraphExtender Graph;
+      typedef MapExtender<DefaultMap<Graph, Arc, _Value> > Parent;
+
+      ArcMap(const Graph& graph) 
+	: Parent(graph) {}
+      ArcMap(const Graph& graph, const _Value& value) 
+	: Parent(graph, value) {}
 
       ArcMap& operator=(const ArcMap& cmap) {
@@ -648,14 +648,14 @@
     template <typename _Value>
     class EdgeMap 
-      : public MapExtender<DefaultMap<Digraph, Edge, _Value> > {
-    public:
-      typedef GraphExtender Digraph;
-      typedef MapExtender<DefaultMap<Digraph, Edge, _Value> > Parent;
-
-      EdgeMap(const Digraph& digraph) 
-	: Parent(digraph) {}
-
-      EdgeMap(const Digraph& digraph, const _Value& value) 
-	: Parent(digraph, value) {}
+      : public MapExtender<DefaultMap<Graph, Edge, _Value> > {
+    public:
+      typedef GraphExtender Graph;
+      typedef MapExtender<DefaultMap<Graph, Edge, _Value> > Parent;
+
+      EdgeMap(const Graph& graph) 
+	: Parent(graph) {}
+
+      EdgeMap(const Graph& graph, const _Value& value) 
+	: Parent(graph, value) {}
 
       EdgeMap& operator=(const EdgeMap& cmap) {
@@ -696,8 +696,8 @@
     }
 
-    template <typename Digraph, typename NodeRefMap, typename EdgeRefMap>
-    void build(const Digraph& digraph, NodeRefMap& nodeRef, 
+    template <typename Graph, typename NodeRefMap, typename EdgeRefMap>
+    void build(const Graph& graph, NodeRefMap& nodeRef, 
                EdgeRefMap& edgeRef) {
-      Parent::build(digraph, nodeRef, edgeRef);
+      Parent::build(graph, nodeRef, edgeRef);
       notifier(Node()).build();
       notifier(Edge()).build();
@@ -724,8 +724,8 @@
 
     void erase(const Edge& edge) {
-      std::vector<Arc> ev;
-      ev.push_back(Parent::direct(edge, true));
-      ev.push_back(Parent::direct(edge, false));      
-      notifier(Arc()).erase(ev);
+      std::vector<Arc> av;
+      av.push_back(Parent::direct(edge, true));
+      av.push_back(Parent::direct(edge, false));      
+      notifier(Arc()).erase(av);
       notifier(Edge()).erase(edge);
       Parent::erase(edge);
Index: lemon/concepts/graph_components.h
===================================================================
--- lemon/concepts/graph_components.h	(revision 57)
+++ lemon/concepts/graph_components.h	(revision 78)
@@ -829,14 +829,14 @@
       /// This iterator goes trough the incident arcs of a certain
       /// node of a graph.
-      typedef GraphIncIt<Graph, Edge, Node, 'u'> IncArcIt;
+      typedef GraphIncIt<Graph, Edge, Node, 'u'> IncEdgeIt;
       /// \brief The base node of the iterator.
       ///
       /// Gives back the base node of the iterator.
-      Node baseNode(const IncArcIt&) const { return INVALID; }
+      Node baseNode(const IncEdgeIt&) const { return INVALID; }
 
       /// \brief The running node of the iterator.
       ///
       /// Gives back the running node of the iterator.
-      Node runningNode(const IncArcIt&) const { return INVALID; }
+      Node runningNode(const IncEdgeIt&) const { return INVALID; }
 
       /// @}
@@ -866,8 +866,8 @@
               typename _Graph::EdgeIt >();
             checkConcept<GraphIncIt<_Graph, typename _Graph::Edge, 
-              typename _Graph::Node, 'u'>, typename _Graph::IncArcIt>();
+              typename _Graph::Node, 'u'>, typename _Graph::IncEdgeIt>();
             
             typename _Graph::Node n;
-            typename _Graph::IncArcIt ueit(INVALID);
+            typename _Graph::IncEdgeIt ueit(INVALID);
             n = graph.baseNode(ueit);
             n = graph.runningNode(ueit);

Index: lemon/concepts/graph.h
===================================================================
--- lemon/concepts/graph.h	(revision 61)
+++ lemon/concepts/graph.h	(revision 78)
@@ -64,5 +64,5 @@
     /// the EdgeMap to map values for the edges. The InArcIt and
     /// OutArcIt iterates on the same edges but with opposite
     /// direction. The IncArcIt iterates also on the same edges
     /// as the OutArcIt and InArcIt but it is not convertible to Arc just
     /// to Edge.  
@@ -271,39 +271,39 @@
       ///\code
       /// int count=0;
-      /// for(Graph::IncArcIt e(g, n); e!=INVALID; ++e) ++count;
+      /// for(Graph::IncEdgeIt e(g, n); e!=INVALID; ++e) ++count;
       ///\endcode
-      class IncArcIt : public Edge {
-      public:
-        /// Default constructor
-
-        /// @warning The default constructor sets the iterator
-        /// to an undefined value.
-        IncArcIt() { }
-        /// Copy constructor.
-
-        /// Copy constructor.
-        ///
-        IncArcIt(const IncArcIt& e) : Edge(e) { }
-        /// Initialize the iterator to be invalid.
-
-        /// Initialize the iterator to be invalid.
-        ///
-        IncArcIt(Invalid) { }
+      class IncEdgeIt : public Edge {
+      public:
+        /// Default constructor
+
+        /// @warning The default constructor sets the iterator
+        /// to an undefined value.
+        IncEdgeIt() { }
+        /// Copy constructor.
+
+        /// Copy constructor.
+        ///
+        IncEdgeIt(const IncEdgeIt& e) : Edge(e) { }
+        /// Initialize the iterator to be invalid.
+
+        /// Initialize the iterator to be invalid.
+        ///
+        IncEdgeIt(Invalid) { }
         /// This constructor sets the iterator to first incident arc.
     
         /// This constructor set the iterator to the first incident arc of
         /// the node.
-        IncArcIt(const Graph&, const Node&) { }
-        /// Edge -> IncArcIt conversion
+        IncEdgeIt(const Graph&, const Node&) { }
+        /// Edge -> IncEdgeIt conversion
 
         /// Sets the iterator to the value of the trivial iterator \c e.
         /// This feature necessitates that each time we 
         /// iterate the arc-set, the iteration order is the same.
-        IncArcIt(const Graph&, const Edge&) { }
+        IncEdgeIt(const Graph&, const Edge&) { }
         /// Next incident arc
 
         /// Assign the iterator to the next incident arc
 	/// of the corresponding node.
-        IncArcIt& operator++() { return *this; }
+        IncEdgeIt& operator++() { return *this; }
       };
 
@@ -721,5 +721,5 @@
       ///
       /// Returns the base node of the iterator
-      Node baseNode(IncArcIt) const {
+      Node baseNode(IncEdgeIt) const {
 	return INVALID;
       }
@@ -728,5 +728,5 @@
       ///
       /// Returns the running node of the iterator
-      Node runningNode(IncArcIt) const {
+      Node runningNode(IncEdgeIt) const {
 	return INVALID;
       }
@@ -64,5 +64,5 @@
     /// the EdgeMap to map values for the edges. The InArcIt and
     /// OutArcIt iterates on the same edges but with opposite
-    /// direction. The IncArcIt iterates also on the same edges
+    /// direction. The IncEdgeIt iterates also on the same edges
     /// as the OutArcIt and InArcIt but it is not convertible to Arc just
     /// to Edge.  